==> DateTime-Locale-1.42.tar.gz: DateTime-Locale-1.42/share/tn-BW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'beke' 'ya' W 'ya' MMM",
    "MMMMW-count-other" => "'beke' 'ya' W 'ya' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'beke' w 'ya' Y",
    "yw-count-other" => "'beke' w 'ya' Y",
  },
  code => "tn-BW",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} 'ka' {0}",
  datetime_format_long => "{1} 'ka' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Mos",
    "Labb",
    "Labr",
    "Labn",
    "Labt",
    "Mat",
    "Tsh",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mosopulogo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labotlhano",
    "Matlhatso",
    "Tshipi",
  ],
  day_stand_alone_abbreviated => [
    "Mos",
    "Labb",
    "Labr",
    "Labn",
    "Labt",
    "Mat",
    "Tsh",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mosopulogo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labotlhano",
    "Matlhatso",
    "Tshipi",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Pele ga tsalo ya Morena Jeso",
    "Morago ga Leso la Morena Jeso",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tswana",
  month_format_abbreviated => [
    "Fer",
    "Tlh",
    "Mop",
    "Mor",
    "Mot",
    "See",
    "Phu",
    "Pha",
    "Lwe",
    "Dip",
    "Ngw",
    "Sed",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Ferikgong",
    "Tlhakole",
    "Mopitlo",
    "Moranang",
    "Motsheganang",
    "Seetebosigo",
    "Phukwi",
    "Phatwe",
    "Lwetse",
    "Diphalane",
    "Ngwanatsele",
    "Sedimonthole",
  ],
  month_stand_alone_abbreviated => [
    "Fer",
    "Tlh",
    "Mop",
    "Mor",
    "Mot",
    "See",
    "Phu",
    "Pha",
    "Lwe",
    "Dip",
    "Ngw",
    "Sed",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Ferikgong",
    "Tlhakole",
    "Mopitlo",
    "Moranang",
    "Motsheganang",
    "Seetebosigo",
    "Phukwi",
    "Phatwe",
    "Lwetse",
    "Diphalane",
    "Ngwanatsele",
    "Sedimonthole",
  ],
  name => "Tswana Botswana",
  native_language => undef,
  native_name => "",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Sephatlho sa ntlha sa ngwaga",
    "Sephatlho sa bobedi",
    "Sephatlho sa boraro",
    "Sephatlho sa bone",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Sephatlho sa ntlha sa ngwaga",
    "Sephatlho sa bobedi",
    "Sephatlho sa boraro",
    "Sephatlho sa bone",
  ],
  script => undef,
  territory => "Botswana",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 45,
}

==> DateTime-Locale-1.44.tar.gz: DateTime-Locale-1.44/share/tn-BW.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'beke' 'ya' W 'ya' MMM",
    "MMMMW-count-other" => "'beke' 'ya' W 'ya' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-one" => "'beke' w 'ya' Y",
    "yw-count-other" => "'beke' w 'ya' Y",
  },
  code => "tn-BW",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} 'ka' {0}",
  datetime_format_long => "{1} 'ka' {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "Mos",
    "Labb",
    "Labr",
    "Labn",
    "Labt",
    "Mat",
    "Tsh",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mosupologo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labotlhano",
    "Matlhatso",
    "Tshipi",
  ],
  day_stand_alone_abbreviated => [
    "Mos",
    "Labb",
    "Labr",
    "Labn",
    "Labt",
    "Mat",
    "Tsh",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mosupologo",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labotlhano",
    "Matlhatso",
    "Tshipi",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Pele ga tsalo ya Morena Jeso",
    "Morago ga Leso la Morena Jeso",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tswana",
  month_format_abbreviated => [
    "Fer",
    "Tlh",
    "Mop",
    "Mor",
    "Mot",
    "See",
    "Phu",
    "Pha",
    "Lwe",
    "Dip",
    "Ngw",
    "Sed",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Ferikgong",
    "Tlhakole",
    "Mopitlo",
    "Moranang",
    "Motsheganang",
    "Seetebosigo",
    "Phukwi",
    "Phatwe",
    "Lwetse",
    "Diphalane",
    "Ngwanatsele",
    "Sedimonthole",
  ],
  month_stand_alone_abbreviated => [
    "Fer",
    "Tlh",
    "Mop",
    "Mor",
    "Mot",
    "See",
    "Phu",
    "Pha",
    "Lwe",
    "Dip",
    "Ngw",
    "Sed",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Ferikgong",
    "Tlhakole",
    "Mopitlo",
    "Moranang",
    "Motsheganang",
    "Seetebosigo",
    "Phukwi",
    "Phatwe",
    "Lwetse",
    "Diphalane",
    "Ngwanatsele",
    "Sedimonthole",
  ],
  name => "Tswana Botswana",
  native_language => "Setswana",
  native_name => "Setswana Botswana",
  native_script => undef,
  native_territory => "Botswana",
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Sephatlho sa ntlha sa ngwaga",
    "Sephatlho sa bobedi",
    "Sephatlho sa boraro",
    "Sephatlho sa bone",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Sephatlho sa ntlha sa ngwaga",
    "Sephatlho sa bobedi",
    "Sephatlho sa boraro",
    "Sephatlho sa bone",
  ],
  script => undef,
  territory => "Botswana",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
